# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DayOfWeekSensor(BaseSensorOperator):
    week_day: "str | Iterable[str] | WeekDay | Iterable[WeekDay]"
    use_task_logical_date: "bool"
    use_task_execution_day: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class S3KeySensor(BaseSensorOperator):
    bucket_key: "str | list[str]"
    bucket_name: "str | None"
    wildcard_match: "bool"
    check_fn: "Callable[..., bool] | None"
    aws_conn_id: "str | None"
    verify: "str | bool | None"
    deferrable: "bool"
    use_regex: "bool"
    metadata_keys: "list[str] | None"


class S3KeysUnchangedSensor(BaseSensorOperator):
    bucket_name: "str"
    prefix: "str"
    aws_conn_id: "str | None"
    verify: "bool | str | None"
    inactivity_period: "float"
    min_objects: "int"
    previous_objects: "set[str] | None"
    allow_delete: "bool"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OSSCreateBucketOperator(BaseOperator):
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDeleteBucketOperator(BaseOperator):
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSUploadObjectOperator(BaseOperator):
    key: "str"
    file: "str"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDownloadObjectOperator(BaseOperator):
    key: "str"
    file: "str"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDeleteBatchObjectOperator(BaseOperator):
    keys: "list"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"


class OSSDeleteObjectOperator(BaseOperator):
    key: "str"
    region: "str"
    bucket_name: "str | None"
    oss_conn_id: "str"



import pytest


def test_convert_dag_params():
    from airfly.cli.utils import convert_dag_params

    assert convert_dag_params(None, None, None) is None

    value = "path:varname"
    param = convert_dag_params(None, None, value)

    assert isinstance(param, tuple)
    assert param[0] == "path"
    assert param[1] == "varname"


def test_expand_sys_path(mocker):
    from airfly.cli.utils import expand_sys_path

    mock_syspath = mocker.patch("sys.path")
    paths = ["path1", "path2"]
    with expand_sys_path(*paths):
        assert mock_syspath.insert.call_count == len(paths)

    assert mock_syspath.pop.call_count == len(paths)


def test_print_version(mocker):
    from airfly.cli.utils import print_version

    mock_click = mocker.patch("airfly.cli.utils.click")
    mock_ctx = mocker.MagicMock()
    mock_ctx.resilient_parsing = None

    print_version(mock_ctx, None, mocker.MagicMock())

    assert mock_click.echo.called
    assert mock_ctx.exit.called


def test_validate_includes():
    from airfly.cli.utils import validate_includes

    with pytest.raises(FileNotFoundError):
        validate_includes(None, None, ["non_existent_path"])


@pytest.mark.parametrize(
    "value,expected",
    [(None, False), (1, True), ("true", True), ("True", True), ("1", True)],
)
def test_convert_task_group(value, expected):
    from airfly.cli.utils import convert_task_group

    assert convert_task_group(None, None, value) is expected



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudNaturalLanguageAnalyzeEntitiesOperator(GoogleCloudBaseOperator):
    document: "dict | Document"
    encoding_type: "EncodingType | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudNaturalLanguageAnalyzeEntitySentimentOperator(GoogleCloudBaseOperator):
    document: "dict | Document"
    encoding_type: "EncodingType | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudNaturalLanguageAnalyzeSentimentOperator(GoogleCloudBaseOperator):
    document: "dict | Document"
    encoding_type: "EncodingType | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudNaturalLanguageClassifyTextOperator(GoogleCloudBaseOperator):
    document: "dict | Document"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GoogleCampaignManagerReportSensor(BaseSensorOperator):
    profile_id: "str"
    report_id: "str"
    file_id: "str"
    api_version: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    mode: "str"
    poke_interval: "int"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class LookerCheckPdtBuildSensor(BaseSensorOperator):
    materialization_id: "str"
    looker_conn_id: "str"
    cancel_on_kill: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class RedshiftDataOperator(AwsBaseOperator):
    database: "str"
    sql: "str | list"
    cluster_identifier: "str | None"
    db_user: "str | None"
    parameters: "list | None"
    secret_arn: "str | None"
    statement_name: "str | None"
    with_event: "bool"
    wait_for_completion: "bool"
    poll_interval: "int"
    return_sql_result: "bool"
    workgroup_name: "str | None"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.sql_to_gcs import (
    BaseSQLToGCSOperator,
)


class TrinoToGCSOperator(BaseSQLToGCSOperator):
    trino_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HttpSensor(BaseSensorOperator):
    endpoint: "str"
    http_conn_id: "str"
    method: "str"
    request_params: "dict[str, Any] | None"
    headers: "dict[str, Any] | None"
    response_error_codes_allowlist: "list[str] | None"
    response_check: "Callable[..., bool] | None"
    extra_options: "dict[str, Any] | None"
    tcp_keep_alive: "bool"
    tcp_keep_alive_idle: "int"
    tcp_keep_alive_count: "int"
    tcp_keep_alive_interval: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.models.skipmixin import SkipMixin
from airfly._vendor.airflow.operators.branch import BranchMixIn


class PythonOperator(BaseOperator):
    python_callable: "Callable"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    templates_dict: "dict[str, Any] | None"
    templates_exts: "Sequence[str] | None"
    show_return_value_in_logs: "bool"


class _BasePythonVirtualenvOperator(PythonOperator):
    python_callable: "Callable"
    serializer: "_SerializerTypeDef | None"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    string_args: "Iterable[str] | None"
    templates_dict: "dict | None"
    templates_exts: "list[str] | None"
    expect_airflow: "bool"
    skip_on_exit_code: "int | Container[int] | None"
    env_vars: "dict[str, str] | None"
    inherit_env: "bool"
    use_dill: "bool"


class ExternalPythonOperator(_BasePythonVirtualenvOperator):
    python: "str"
    python_callable: "Callable"
    serializer: "_SerializerTypeDef | None"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    string_args: "Iterable[str] | None"
    templates_dict: "dict | None"
    templates_exts: "list[str] | None"
    expect_airflow: "bool"
    expect_pendulum: "bool"
    skip_on_exit_code: "int | Container[int] | None"
    env_vars: "dict[str, str] | None"
    inherit_env: "bool"
    use_dill: "bool"


class BranchExternalPythonOperator(ExternalPythonOperator, BranchMixIn):
    python: "str"
    python_callable: "Callable"
    serializer: "_SerializerTypeDef | None"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    string_args: "Iterable[str] | None"
    templates_dict: "dict | None"
    templates_exts: "list[str] | None"
    expect_airflow: "bool"
    expect_pendulum: "bool"
    skip_on_exit_code: "int | Container[int] | None"
    env_vars: "dict[str, str] | None"
    inherit_env: "bool"
    use_dill: "bool"


class BranchPythonOperator(PythonOperator, BranchMixIn):
    python_callable: "Callable"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    templates_dict: "dict[str, Any] | None"
    templates_exts: "Sequence[str] | None"
    show_return_value_in_logs: "bool"


class PythonVirtualenvOperator(_BasePythonVirtualenvOperator):
    python_callable: "Callable"
    requirements: "None | Iterable[str] | str"
    python_version: "str | None"
    serializer: "_SerializerTypeDef | None"
    system_site_packages: "bool"
    pip_install_options: "list[str] | None"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    string_args: "Iterable[str] | None"
    templates_dict: "dict | None"
    templates_exts: "list[str] | None"
    expect_airflow: "bool"
    skip_on_exit_code: "int | Container[int] | None"
    index_urls: "None | Collection[str] | str"
    venv_cache_path: "None | os.PathLike[str]"
    env_vars: "dict[str, str] | None"
    inherit_env: "bool"
    use_dill: "bool"


class BranchPythonVirtualenvOperator(PythonVirtualenvOperator, BranchMixIn):
    python_callable: "Callable"
    requirements: "None | Iterable[str] | str"
    python_version: "str | None"
    serializer: "_SerializerTypeDef | None"
    system_site_packages: "bool"
    pip_install_options: "list[str] | None"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    string_args: "Iterable[str] | None"
    templates_dict: "dict | None"
    templates_exts: "list[str] | None"
    expect_airflow: "bool"
    skip_on_exit_code: "int | Container[int] | None"
    index_urls: "None | Collection[str] | str"
    venv_cache_path: "None | os.PathLike[str]"
    env_vars: "dict[str, str] | None"
    inherit_env: "bool"
    use_dill: "bool"


class ShortCircuitOperator(PythonOperator, SkipMixin):
    ignore_downstream_trigger_rules: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BaseSqlToSlackOperator(BaseOperator):
    sql: "str"
    sql_conn_id: "str"
    sql_hook_params: "dict | None"
    parameters: "list | tuple | Mapping[str, Any] | None"
    slack_proxy: "str | None"
    slack_timeout: "int | None"
    slack_retry_handlers: "list[RetryHandler] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GlueJobSensor(BaseSensorOperator):
    job_name: "str"
    run_id: "str"
    verbose: "bool"
    aws_conn_id: "str | None"


class GlueDataQualityRuleSetEvaluationRunSensor(AwsBaseSensor):
    evaluation_run_id: "str"
    show_results: "bool"
    verify_result_status: "bool"
    deferrable: "bool"
    poke_interval: "int"
    max_retries: "int"
    aws_conn_id: "str | None"


class GlueDataQualityRuleRecommendationRunSensor(AwsBaseSensor):
    recommendation_run_id: "str"
    show_results: "bool"
    deferrable: "bool"
    poke_interval: "int"
    max_retries: "int"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.sql_to_gcs import (
    BaseSQLToGCSOperator,
)


class MSSQLToGCSOperator(BaseSQLToGCSOperator):
    bit_fields: "Sequence[str] | None"
    mssql_conn_id: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.common.sql.operators.sql import (
    SQLExecuteQueryOperator,
)


class ExasolOperator(SQLExecuteQueryOperator):
    exasol_conn_id: "str"
    schema: "str | None"
    handler: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class EmrAddStepsOperator(BaseOperator):
    job_flow_id: "str | None"
    job_flow_name: "str | None"
    cluster_states: "list[str] | None"
    aws_conn_id: "str | None"
    steps: "list[dict] | str | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    execution_role_arn: "str | None"
    deferrable: "bool"


class EmrStartNotebookExecutionOperator(BaseOperator):
    editor_id: "str"
    relative_path: "str"
    cluster_id: "str"
    service_role: "str"
    notebook_execution_name: "str | None"
    notebook_params: "str | None"
    notebook_instance_security_group_id: "str | None"
    master_instance_security_group_id: "str | None"
    tags: "list | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    waiter_max_attempts: "int | None"
    waiter_delay: "int | None"
    waiter_countdown: "int | None"
    waiter_check_interval_seconds: "int | None"


class EmrStopNotebookExecutionOperator(BaseOperator):
    notebook_execution_id: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    waiter_max_attempts: "int | None"
    waiter_delay: "int | None"
    waiter_countdown: "int | None"
    waiter_check_interval_seconds: "int | None"


class EmrEksCreateClusterOperator(BaseOperator):
    virtual_cluster_name: "str"
    eks_cluster_name: "str"
    eks_namespace: "str"
    virtual_cluster_id: "str"
    aws_conn_id: "str | None"
    tags: "dict | None"


class EmrContainerOperator(BaseOperator):
    name: "str"
    virtual_cluster_id: "str"
    execution_role_arn: "str"
    release_label: "str"
    job_driver: "dict"
    configuration_overrides: "dict | None"
    client_request_token: "str | None"
    aws_conn_id: "str | None"
    wait_for_completion: "bool"
    poll_interval: "int"
    max_tries: "int | None"
    tags: "dict | None"
    max_polling_attempts: "int | None"
    job_retry_max_attempts: "int | None"
    deferrable: "bool"


class EmrCreateJobFlowOperator(BaseOperator):
    aws_conn_id: "str | None"
    emr_conn_id: "str | None"
    job_flow_overrides: "str | dict[str, Any] | None"
    region_name: "str | None"
    wait_for_completion: "bool"
    waiter_max_attempts: "int | None"
    waiter_delay: "int | None"
    waiter_countdown: "int | None"
    waiter_check_interval_seconds: "int | None"
    deferrable: "bool"


class EmrModifyClusterOperator(BaseOperator):
    cluster_id: "str"
    step_concurrency_level: "int"
    aws_conn_id: "str | None"


class EmrTerminateJobFlowOperator(BaseOperator):
    job_flow_id: "str"
    aws_conn_id: "str | None"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EmrServerlessCreateApplicationOperator(BaseOperator):
    release_label: "str"
    job_type: "str"
    client_request_token: "str"
    config: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    waiter_countdown: "int | ArgNotSet"
    waiter_check_interval_seconds: "int | ArgNotSet"
    waiter_max_attempts: "int | ArgNotSet"
    waiter_delay: "int | ArgNotSet"
    deferrable: "bool"


class EmrServerlessStartJobOperator(BaseOperator):
    application_id: "str"
    execution_role_arn: "str"
    job_driver: "dict"
    configuration_overrides: "dict | None"
    client_request_token: "str"
    config: "dict | None"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    name: "str | None"
    waiter_countdown: "int | ArgNotSet"
    waiter_check_interval_seconds: "int | ArgNotSet"
    waiter_max_attempts: "int | ArgNotSet"
    waiter_delay: "int | ArgNotSet"
    deferrable: "bool"
    enable_application_ui_links: "bool"


class EmrServerlessStopApplicationOperator(BaseOperator):
    application_id: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    waiter_countdown: "int | ArgNotSet"
    waiter_check_interval_seconds: "int | ArgNotSet"
    waiter_max_attempts: "int | ArgNotSet"
    waiter_delay: "int | ArgNotSet"
    force_stop: "bool"
    deferrable: "bool"


class EmrServerlessDeleteApplicationOperator(EmrServerlessStopApplicationOperator):
    application_id: "str"
    wait_for_completion: "bool"
    aws_conn_id: "str | None"
    waiter_countdown: "int | ArgNotSet"
    waiter_check_interval_seconds: "int | ArgNotSet"
    waiter_max_attempts: "int | ArgNotSet"
    waiter_delay: "int | ArgNotSet"
    force_stop: "bool"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class LevelDBOperator(BaseOperator):
    command: "str"
    key: "bytes"
    value: "bytes | None"
    keys: "list[bytes] | None"
    values: "list[bytes] | None"
    leveldb_conn_id: "str"
    name: "str"
    create_if_missing: "bool"
    create_db_extra_options: "dict[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBlobStorageToS3Operator(BaseOperator):
    wasb_conn_id: "str"
    container_name: "str"
    prefix: "str | None"
    delimiter: "str"
    aws_conn_id: "str | None"
    dest_s3_key: "str"
    dest_verify: "str | bool | None"
    dest_s3_extra_args: "dict | None"
    replace: "bool"
    s3_acl_policy: "str | None"
    wasb_extra_args: "dict | None"
    s3_extra_args: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OracleToOracleOperator(BaseOperator):
    oracle_destination_conn_id: "str"
    destination_table: "str"
    oracle_source_conn_id: "str"
    source_sql: "str"
    source_sql_params: "dict | None"
    rows_chunk: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.common.sql.operators.sql import (
    SQLExecuteQueryOperator,
)


class YDBExecuteQueryOperator(SQLExecuteQueryOperator):
    sql: "str | list[str]"
    is_ddl: "bool"
    ydb_conn_id: "str"
    parameters: "Mapping | Iterable | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DataflowJobStatusSensor(BaseSensorOperator):
    job_id: "str"
    expected_statuses: "set[str] | str"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"


class DataflowJobMetricsSensor(BaseSensorOperator):
    job_id: "str"
    callback: "Callable | None"
    fail_on_terminal_state: "bool"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"


class DataflowJobMessagesSensor(BaseSensorOperator):
    job_id: "str"
    callback: "Callable | None"
    fail_on_terminal_state: "bool"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"


class DataflowJobAutoScalingEventsSensor(BaseSensorOperator):
    job_id: "str"
    callback: "Callable | None"
    fail_on_terminal_state: "bool"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class BigQueryCreateDataTransferOperator(GoogleCloudBaseOperator):
    transfer_config: "dict"
    project_id: "str"
    location: "str | None"
    authorization_code: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "_empty"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryDeleteDataTransferConfigOperator(GoogleCloudBaseOperator):
    transfer_config_id: "str"
    project_id: "str"
    location: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "_empty"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryDataTransferServiceStartTransferRunsOperator(GoogleCloudBaseOperator):
    transfer_config_id: "str"
    project_id: "str"
    location: "str | None"
    requested_time_range: "dict | None"
    requested_run_time: "dict | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "_empty"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.common.sql.operators.sql import (
    SQLExecuteQueryOperator,
)


class TeradataOperator(SQLExecuteQueryOperator):
    teradata_conn_id: "str"
    schema: "str | None"


class TeradataStoredProcedureOperator(BaseOperator):
    procedure: "str"
    teradata_conn_id: "str"
    parameters: "dict | list | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.slack.transfers.base_sql_to_slack import (
    BaseSqlToSlackOperator,
)
from airfly._vendor.airflow.providers.slack.transfers.sql_to_slack_webhook import (
    SqlToSlackWebhookOperator,
)


class SqlToSlackApiFileOperator(BaseSqlToSlackOperator):
    sql: "str"
    sql_conn_id: "str"
    sql_hook_params: "dict | None"
    parameters: "list | tuple | Mapping[str, Any] | None"
    slack_conn_id: "str"
    slack_filename: "str"
    slack_channels: "str | Sequence[str] | None"
    slack_initial_comment: "str | None"
    slack_title: "str | None"
    slack_base_url: "str | None"
    slack_method_version: "Literal['v1', 'v2']"
    df_kwargs: "dict | None"
    action_on_empty_df: "Literal['send', 'skip', 'error']"


class SqlToSlackOperator(SqlToSlackWebhookOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BatchSensor(BaseSensorOperator):
    job_id: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"
    deferrable: "bool"
    poke_interval: "float"
    max_retries: "int"


class BatchComputeEnvironmentSensor(BaseSensorOperator):
    compute_environment: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"


class BatchJobQueueSensor(BaseSensorOperator):
    job_queue: "str"
    treat_non_existing_as_deleted: "bool"
    aws_conn_id: "str | None"
    region_name: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class ComprehendBaseOperator(AwsBaseOperator):
    input_data_config: "dict"
    output_data_config: "dict"
    data_access_role_arn: "str"
    language_code: "str"


class ComprehendStartPiiEntitiesDetectionJobOperator(ComprehendBaseOperator):
    input_data_config: "dict"
    output_data_config: "dict"
    mode: "str"
    data_access_role_arn: "str"
    language_code: "str"
    start_pii_entities_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class ComprehendCreateDocumentClassifierOperator(AwsBaseOperator):
    document_classifier_name: "str"
    input_data_config: "dict[str, Any]"
    mode: "str"
    data_access_role_arn: "str"
    language_code: "str"
    fail_on_warnings: "bool"
    output_data_config: "dict[str, Any] | None"
    document_classifier_kwargs: "dict[str, Any] | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.common.sql.operators.sql import (
    SQLCheckOperator,
    SQLColumnCheckOperator,
    SQLIntervalCheckOperator,
    SQLTableCheckOperator,
    SQLValueCheckOperator,
)
from airfly._vendor.airflow.providers.google.cloud.openlineage.mixins import (
    _BigQueryOpenLineageMixin,
)
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class BigQueryCreateEmptyDatasetOperator(GoogleCloudBaseOperator):
    dataset_id: "str | None"
    project_id: "str"
    dataset_reference: "dict | None"
    location: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    if_exists: "str"
    exists_ok: "bool | None"


class BigQueryCreateEmptyTableOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    table_id: "str"
    table_resource: "dict[str, Any] | None"
    project_id: "str"
    schema_fields: "list | None"
    gcs_schema_object: "str | None"
    time_partitioning: "dict | None"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "str"
    labels: "dict | None"
    view: "dict | None"
    materialized_view: "dict | None"
    encryption_configuration: "dict | None"
    location: "str | None"
    cluster_fields: "list[str] | None"
    impersonation_chain: "str | Sequence[str] | None"
    if_exists: "str"
    bigquery_conn_id: "str | None"
    exists_ok: "bool | None"


class BigQueryDeleteDatasetOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    project_id: "str"
    delete_contents: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryInsertJobOperator(GoogleCloudBaseOperator, _BigQueryOpenLineageMixin):
    configuration: "dict[str, Any]"
    project_id: "str"
    location: "str | None"
    job_id: "str | None"
    force_rerun: "bool"
    reattach_states: "set[str] | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    cancel_on_kill: "bool"
    result_retry: "Retry"
    result_timeout: "float | None"
    deferrable: "bool"
    poll_interval: "float"


class BigQueryCreateExternalTableOperator(GoogleCloudBaseOperator):
    bucket: "str | None"
    source_objects: "list[str] | None"
    destination_project_dataset_table: "str | None"
    table_resource: "dict[str, Any] | None"
    schema_fields: "list | None"
    schema_object: "str | None"
    gcs_schema_bucket: "str | None"
    source_format: "str | None"
    autodetect: "bool"
    compression: "str | None"
    skip_leading_rows: "int | None"
    field_delimiter: "str | None"
    max_bad_records: "int"
    quote_character: "str | None"
    allow_quoted_newlines: "bool"
    allow_jagged_rows: "bool"
    gcp_conn_id: "str"
    google_cloud_storage_conn_id: "str"
    src_fmt_configs: "dict | None"
    labels: "dict | None"
    encryption_configuration: "dict | None"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    bigquery_conn_id: "str | None"


class _BigQueryDbHookMixin:
    pass


class _BigQueryOperatorsEncryptionConfigurationMixin:
    pass


class BigQueryCheckOperator(
    _BigQueryDbHookMixin,
    SQLCheckOperator,
    _BigQueryOperatorsEncryptionConfigurationMixin,
):
    sql: "str"
    gcp_conn_id: "str"
    use_legacy_sql: "bool"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    labels: "dict | None"
    encryption_configuration: "dict | None"
    deferrable: "bool"
    poll_interval: "float"
    query_params: "list | None"


class BigQueryValueCheckOperator(
    _BigQueryDbHookMixin,
    SQLValueCheckOperator,
    _BigQueryOperatorsEncryptionConfigurationMixin,
):
    sql: "str"
    pass_value: "Any"
    tolerance: "Any"
    encryption_configuration: "dict | None"
    gcp_conn_id: "str"
    use_legacy_sql: "bool"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    labels: "dict | None"
    deferrable: "bool"
    poll_interval: "float"


class BigQueryIntervalCheckOperator(
    _BigQueryDbHookMixin,
    SQLIntervalCheckOperator,
    _BigQueryOperatorsEncryptionConfigurationMixin,
):
    table: "str"
    metrics_thresholds: "dict"
    date_filter_column: "str"
    days_back: "SupportsAbs[int]"
    gcp_conn_id: "str"
    use_legacy_sql: "bool"
    location: "str | None"
    encryption_configuration: "dict | None"
    impersonation_chain: "str | Sequence[str] | None"
    labels: "dict | None"
    deferrable: "bool"
    poll_interval: "float"
    project_id: "str"


class BigQueryColumnCheckOperator(
    _BigQueryDbHookMixin,
    SQLColumnCheckOperator,
    _BigQueryOperatorsEncryptionConfigurationMixin,
):
    table: "str"
    column_mapping: "dict"
    partition_clause: "str | None"
    database: "str | None"
    accept_none: "bool"
    encryption_configuration: "dict | None"
    gcp_conn_id: "str"
    use_legacy_sql: "bool"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    labels: "dict | None"


class BigQueryTableCheckOperator(
    _BigQueryDbHookMixin,
    SQLTableCheckOperator,
    _BigQueryOperatorsEncryptionConfigurationMixin,
):
    table: "str"
    checks: "dict"
    partition_clause: "str | None"
    gcp_conn_id: "str"
    use_legacy_sql: "bool"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    labels: "dict | None"
    encryption_configuration: "dict | None"


class BigQueryGetDataOperator(
    GoogleCloudBaseOperator,
    _BigQueryOperatorsEncryptionConfigurationMixin,
):
    dataset_id: "str | None"
    table_id: "str | None"
    table_project_id: "str | None"
    job_id: "str | None"
    job_project_id: "str | None"
    project_id: "str"
    max_results: "int"
    selected_fields: "str | None"
    gcp_conn_id: "str"
    location: "str | None"
    encryption_configuration: "dict | None"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "float"
    as_dict: "bool"
    use_legacy_sql: "bool"


class BigQueryExecuteQueryOperator(GoogleCloudBaseOperator):
    pass


class BigQueryGetDatasetOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryGetDatasetTablesOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    project_id: "str"
    max_results: "int | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryPatchDatasetOperator(GoogleCloudBaseOperator):
    pass


class BigQueryUpdateTableOperator(GoogleCloudBaseOperator):
    table_resource: "dict[str, Any]"
    fields: "list[str] | None"
    dataset_id: "str | None"
    table_id: "str | None"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryUpdateDatasetOperator(GoogleCloudBaseOperator):
    dataset_resource: "dict[str, Any]"
    fields: "list[str] | None"
    dataset_id: "str | None"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryDeleteTableOperator(GoogleCloudBaseOperator):
    deletion_dataset_table: "str"
    gcp_conn_id: "str"
    ignore_if_missing: "bool"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryUpsertTableOperator(GoogleCloudBaseOperator):
    dataset_id: "str"
    table_resource: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"


class BigQueryUpdateTableSchemaOperator(GoogleCloudBaseOperator):
    schema_fields_updates: "list[dict[str, Any]]"
    dataset_id: "str"
    table_id: "str"
    include_policy_tags: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    location: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.bigquery_to_sql import (
    BigQueryToSqlBaseOperator,
)


class BigQueryToPostgresOperator(BigQueryToSqlBaseOperator):
    target_table_name: "str"
    postgres_conn_id: "str"
    replace: "bool"
    selected_fields: "list[str] | str | None"
    replace_index: "list[str] | str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudFunctionDeployFunctionOperator(GoogleCloudBaseOperator):
    location: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    zip_path: "str | None"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class CloudFunctionDeleteFunctionOperator(GoogleCloudBaseOperator):
    name: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"
    project_id: "str"


class CloudFunctionInvokeFunctionOperator(GoogleCloudBaseOperator):
    function_id: "str"
    input_data: "dict"
    location: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.common.sql.operators.sql import BaseSQLOperator


class SQLToGoogleSheetsOperator(BaseSQLOperator):
    sql: "str"
    spreadsheet_id: "str"
    sql_conn_id: "str"
    parameters: "Iterable | Mapping[str, Any] | None"
    database: "str | None"
    spreadsheet_range: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DataflowCreateJavaJobOperator(GoogleCloudBaseOperator):
    pass


class DataflowTemplatedJobStartOperator(GoogleCloudBaseOperator):
    template: "str"
    project_id: "str"
    job_name: "str"
    options: "dict[str, Any] | None"
    dataflow_default_options: "dict[str, Any] | None"
    parameters: "dict[str, str] | None"
    location: "str | None"
    gcp_conn_id: "str"
    poll_sleep: "int"
    impersonation_chain: "str | Sequence[str] | None"
    environment: "dict | None"
    cancel_timeout: "int | None"
    wait_until_finished: "bool | None"
    append_job_name: "bool"
    deferrable: "bool"
    expected_terminal_state: "str | None"


class DataflowStartFlexTemplateOperator(GoogleCloudBaseOperator):
    body: "dict"
    location: "str"
    project_id: "str"
    gcp_conn_id: "str"
    drain_pipeline: "bool"
    cancel_timeout: "int | None"
    wait_until_finished: "bool | None"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    append_job_name: "bool"
    expected_terminal_state: "str | None"
    poll_sleep: "int"


class DataflowStartSqlJobOperator(GoogleCloudBaseOperator):
    job_name: "str"
    query: "str"
    options: "dict[str, Any]"
    location: "str"
    project_id: "str"
    gcp_conn_id: "str"
    drain_pipeline: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class DataflowCreatePythonJobOperator(GoogleCloudBaseOperator):
    pass


class DataflowStopJobOperator(GoogleCloudBaseOperator):
    job_name_prefix: "str | None"
    job_id: "str | None"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    poll_sleep: "int"
    impersonation_chain: "str | Sequence[str] | None"
    stop_timeout: "int | None"
    drain_pipeline: "bool"


class DataflowCreatePipelineOperator(GoogleCloudBaseOperator):
    body: "dict"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataflowRunPipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataflowDeletePipelineOperator(GoogleCloudBaseOperator):
    pipeline_name: "str"
    project_id: "str"
    location: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SalesforceToS3Operator(BaseOperator):
    salesforce_query: "str"
    s3_bucket_name: "str"
    s3_key: "str"
    salesforce_conn_id: "str"
    export_format: "str"
    query_params: "dict | None"
    include_deleted: "bool"
    coerce_to_timestamp: "bool"
    record_time_added: "bool"
    aws_conn_id: "str | None"
    replace: "bool"
    encrypt: "bool"
    gzip: "bool"
    acl_policy: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudTasksQueueCreateOperator(GoogleCloudBaseOperator):
    location: "str"
    task_queue: "Queue"
    project_id: "str"
    queue_name: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueUpdateOperator(GoogleCloudBaseOperator):
    task_queue: "Queue"
    project_id: "str"
    location: "str | None"
    queue_name: "str | None"
    update_mask: "FieldMask | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueGetOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueuesListOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    results_filter: "str | None"
    page_size: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueDeleteOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueuePurgeOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueuePauseOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksQueueResumeOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskCreateOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task: "dict | Task"
    project_id: "str"
    task_name: "str | None"
    response_view: "Task.View | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskGetOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "str"
    response_view: "Task.View | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTasksListOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    project_id: "str"
    response_view: "Task.View | None"
    page_size: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskDeleteOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudTasksTaskRunOperator(GoogleCloudBaseOperator):
    location: "str"
    queue_name: "str"
    task_name: "str"
    project_id: "str"
    response_view: "Task.View | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "MetaData"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class CloudDataFusionPipelineStateSensor(BaseSensorOperator):
    pipeline_name: "str"
    pipeline_id: "str"
    expected_statuses: "Iterable[str]"
    instance_name: "str"
    location: "str"
    failure_statuses: "Iterable[str] | None"
    project_id: "str"
    namespace: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class DataprocJobSensor(BaseSensorOperator):
    dataproc_job_id: "str"
    region: "str"
    project_id: "str"
    gcp_conn_id: "str"
    wait_timeout: "int | None"


class DataprocBatchSensor(BaseSensorOperator):
    batch_id: "str"
    region: "str"
    project_id: "str"
    gcp_conn_id: "str"
    wait_timeout: "int | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class BigQueryToSqlBaseOperator(BaseOperator):
    dataset_table: "str"
    target_table_name: "str | None"
    selected_fields: "list[str] | str | None"
    gcp_conn_id: "str"
    database: "str | None"
    replace: "bool"
    batch_size: "int"
    location: "str | None"
    impersonation_chain: "str | Sequence[str] | None"
    dataset_id: "str | None"
    table_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class FTPFileTransmitOperator(BaseOperator):
    ftp_conn_id: "str"
    local_filepath: "str | list[str]"
    remote_filepath: "str | list[str]"
    operation: "str"
    create_intermediate_dirs: "bool"


class FTPSFileTransmitOperator(FTPFileTransmitOperator):
    ftp_conn_id: "str"
    local_filepath: "str | list[str]"
    remote_filepath: "str | list[str]"
    operation: "str"
    create_intermediate_dirs: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToGCSOperator(BaseOperator):
    source_bucket: "_empty"
    source_object: "_empty"
    source_objects: "_empty"
    destination_bucket: "_empty"
    destination_object: "_empty"
    delimiter: "_empty"
    move_object: "_empty"
    replace: "_empty"
    gcp_conn_id: "_empty"
    last_modified_time: "_empty"
    maximum_modified_time: "_empty"
    is_older_than: "_empty"
    impersonation_chain: "str | Sequence[str] | None"
    source_object_required: "_empty"
    exact_match: "_empty"
    match_glob: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleSheetsCreateSpreadsheetOperator(BaseOperator):
    spreadsheet: "dict[str, Any]"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class HivePartitionSensor(BaseSensorOperator):
    table: "str"
    partition: "str | None"
    metastore_conn_id: "str"
    schema: "str"
    poke_interval: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SalesforceApexRestOperator(BaseOperator):
    endpoint: "str"
    method: "str"
    payload: "dict"
    salesforce_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class AthenaOperator(AwsBaseOperator):
    query: "str"
    database: "str"
    output_location: "str | None"
    client_request_token: "str | None"
    workgroup: "str"
    query_execution_context: "dict[str, str] | None"
    result_configuration: "dict[str, Any] | None"
    sleep_time: "int"
    max_polling_attempts: "int | None"
    log_query: "bool"
    deferrable: "bool"
    catalog: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class BedrockBaseSensor(AwsBaseSensor):
    deferrable: "bool"


class BedrockCustomizeModelCompletedSensor(BedrockBaseSensor):
    job_name: "str"
    max_retries: "int"
    poke_interval: "int"


class BedrockProvisionModelThroughputCompletedSensor(BedrockBaseSensor):
    model_id: "str"
    poke_interval: "int"
    max_retries: "int"


class BedrockKnowledgeBaseActiveSensor(BedrockBaseSensor):
    knowledge_base_id: "str"
    poke_interval: "int"
    max_retries: "int"


class BedrockIngestionJobSensor(BedrockBaseSensor):
    knowledge_base_id: "str"
    data_source_id: "str"
    ingestion_job_id: "str"
    poke_interval: "int"
    max_retries: "int"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GCSToS3Operator(BaseOperator):
    gcs_bucket: "str | None"
    bucket: "str | None"
    prefix: "str | None"
    delimiter: "str | None"
    gcp_conn_id: "str"
    dest_aws_conn_id: "str | None"
    dest_s3_key: "str"
    dest_verify: "str | bool | None"
    replace: "bool"
    google_impersonation_chain: "str | Sequence[str] | None"
    dest_s3_extra_args: "dict | None"
    s3_acl_policy: "str | None"
    keep_directory_structure: "bool"
    match_glob: "str | None"
    gcp_user_project: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class RdsBaseSensor(BaseSensorOperator):
    aws_conn_id: "str | None"
    hook_params: "dict | None"


class RdsSnapshotExistenceSensor(RdsBaseSensor):
    db_type: "str"
    db_snapshot_identifier: "str"
    target_statuses: "list[str] | None"
    aws_conn_id: "str | None"


class RdsExportTaskExistenceSensor(RdsBaseSensor):
    export_task_identifier: "str"
    target_statuses: "list[str] | None"
    aws_conn_id: "str | None"


class RdsDbSensor(RdsBaseSensor):
    db_identifier: "str"
    db_type: "RdsDbType | str"
    target_statuses: "list[str] | None"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureBlobStorageToGCSOperator(BaseOperator):
    wasb_conn_id: "_empty"
    gcp_conn_id: "str"
    blob_name: "str"
    container_name: "str"
    bucket_name: "str"
    object_name: "str"
    filename: "str"
    gzip: "bool"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class BigQueryTableExistenceSensor(BaseSensorOperator):
    project_id: "str"
    dataset_id: "str"
    table_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"


class BigQueryTablePartitionExistenceSensor(BaseSensorOperator):
    project_id: "str"
    dataset_id: "str"
    table_id: "str"
    partition_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"


class BigQueryTableExistenceAsyncSensor(BigQueryTableExistenceSensor):
    pass


class BigQueryTableExistencePartitionAsyncSensor(BigQueryTablePartitionExistenceSensor):
    pass



import os
import sys
from contextlib import contextmanager

import click


def print_version(ctx, param, value):
    if (not value) or ctx.resilient_parsing:
        return

    from airfly import __version__

    click.echo(f"Version: {__version__}")

    ctx.exit()


@contextmanager
def expand_sys_path(*paths: str):

    num = len(paths)

    for p in paths[::-1]:
        if p and isinstance(p, str):

            sys.path.insert(0, p)

    yield

    for _ in range(num):
        sys.path.pop(0)


def validate_includes(ctx, param, value):
    if value:
        for inc in value:
            if not os.path.isfile(inc):
                raise FileNotFoundError(f"Invalid file, got: {inc}")

        return list(value)

    return value


def convert_dag_params(ctx, param, value):

    if not value:
        return None

    elif isinstance(value, tuple):
        return value

    try:
        pypath, _, varname = value.partition(":")
        return pypath, varname

    except ValueError:
        raise click.BadParameter("format must be '<python-file>:<variable>'")


def convert_task_group(ctx, param, value):

    if isinstance(value, bool):
        return value

    if isinstance(value, int):
        return value == 1

    if isinstance(value, str):
        return value.lower() == "true" or value == "1"

    return False



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class _TeradataComputeClusterOperator(BaseOperator):
    compute_profile_name: "str"
    compute_group_name: "str | None"
    teradata_conn_id: "str"
    timeout: "int"


class TeradataComputeClusterProvisionOperator(_TeradataComputeClusterOperator):
    query_strategy: "str | None"
    compute_map: "str | None"
    compute_attribute: "str | None"


class TeradataComputeClusterDecommissionOperator(_TeradataComputeClusterOperator):
    delete_compute_group: "bool"


class TeradataComputeClusterResumeOperator(_TeradataComputeClusterOperator):
    pass


class TeradataComputeClusterSuspendOperator(_TeradataComputeClusterOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GithubOperator(BaseOperator):
    github_method: "str"
    github_conn_id: "str"
    github_method_args: "dict | None"
    result_processor: "Callable | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleAnalyticsListAccountsOperator(BaseOperator):
    pass


class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
    pass


class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
    pass


class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
    pass


class GoogleAnalyticsDeletePreviousDataUploadsOperator(BaseOperator):
    pass


class GoogleAnalyticsModifyFileHeadersDataImportOperator(BaseOperator):
    storage_bucket: "str"
    storage_name_object: "str"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    custom_dimension_header_mapping: "dict[str, str] | None"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DruidOperator(BaseOperator):
    json_index_file: "str"
    druid_ingest_conn_id: "str"
    timeout: "int"
    max_ingestion_time: "int | None"
    ingestion_type: "IngestionType"
    verify_ssl: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class WasbDeleteBlobOperator(BaseOperator):
    container_name: "str"
    blob_name: "str"
    wasb_conn_id: "str"
    check_options: "Any"
    is_prefix: "bool"
    ignore_if_missing: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class StackdriverListAlertPoliciesOperator(GoogleCloudBaseOperator):
    format_: "str | None"
    filter_: "str | None"
    order_by: "str | None"
    page_size: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverEnableAlertPoliciesOperator(GoogleCloudBaseOperator):
    filter_: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverDisableAlertPoliciesOperator(GoogleCloudBaseOperator):
    filter_: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverUpsertAlertOperator(GoogleCloudBaseOperator):
    alerts: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverDeleteAlertOperator(GoogleCloudBaseOperator):
    name: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverListNotificationChannelsOperator(GoogleCloudBaseOperator):
    format_: "str | None"
    filter_: "str | None"
    order_by: "str | None"
    page_size: "int | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverEnableNotificationChannelsOperator(GoogleCloudBaseOperator):
    filter_: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverDisableNotificationChannelsOperator(GoogleCloudBaseOperator):
    filter_: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverUpsertNotificationChannelOperator(GoogleCloudBaseOperator):
    channels: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class StackdriverDeleteNotificationChannelOperator(GoogleCloudBaseOperator):
    name: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    project_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class KubernetesResourceBaseOperator(BaseOperator):
    yaml_conf: "str | None"
    yaml_conf_file: "str | None"
    namespace: "str | None"
    kubernetes_conn_id: "str | None"
    custom_resource_definition: "bool"
    namespaced: "bool"
    config_file: "str | None"


class KubernetesCreateResourceOperator(KubernetesResourceBaseOperator):
    yaml_conf: "str | None"
    yaml_conf_file: "str | None"
    namespace: "str | None"
    kubernetes_conn_id: "str | None"
    custom_resource_definition: "bool"
    namespaced: "bool"
    config_file: "str | None"


class KubernetesDeleteResourceOperator(KubernetesResourceBaseOperator):
    yaml_conf: "str | None"
    yaml_conf_file: "str | None"
    namespace: "str | None"
    kubernetes_conn_id: "str | None"
    custom_resource_definition: "bool"
    namespaced: "bool"
    config_file: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class GlueCrawlerOperator(AwsBaseOperator):
    config: "_empty"
    poll_interval: "int"
    wait_for_completion: "bool"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudMemorystoreCreateInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance_id: "str"
    instance: "dict | Instance"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreDeleteInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreExportInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    output_config: "dict | OutputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreFailoverInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    data_protection_mode: "FailoverInstanceRequest.DataProtectionMode"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreGetInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreImportOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    input_config: "dict | InputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreListInstancesOperator(GoogleCloudBaseOperator):
    location: "str"
    page_size: "int"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreUpdateInstanceOperator(GoogleCloudBaseOperator):
    update_mask: "dict | FieldMask"
    instance: "dict | Instance"
    location: "str | None"
    instance_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreScaleInstanceOperator(GoogleCloudBaseOperator):
    memory_size_gb: "int"
    location: "str | None"
    instance_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreCreateInstanceAndImportOperator(GoogleCloudBaseOperator):
    location: "str"
    instance_id: "str"
    instance: "dict | Instance"
    input_config: "dict | InputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreExportAndDeleteInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    output_config: "dict | OutputConfig"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedApplyParametersOperator(GoogleCloudBaseOperator):
    node_ids: "Sequence[str]"
    apply_all: "bool"
    location: "str"
    instance_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedCreateInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance_id: "str"
    instance: "dict | cloud_memcache.Instance"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"


class CloudMemorystoreMemcachedDeleteInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"


class CloudMemorystoreMemcachedGetInstanceOperator(GoogleCloudBaseOperator):
    location: "str"
    instance: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedListInstancesOperator(GoogleCloudBaseOperator):
    location: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedUpdateInstanceOperator(GoogleCloudBaseOperator):
    update_mask: "dict | FieldMask"
    instance: "dict | cloud_memcache.Instance"
    location: "str | None"
    instance_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudMemorystoreMemcachedUpdateParametersOperator(GoogleCloudBaseOperator):
    update_mask: "dict | FieldMask"
    parameters: "dict | cloud_memcache.MemcacheParameters"
    location: "str"
    instance_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class RdsBaseOperator(BaseOperator):
    aws_conn_id: "str | None"
    region_name: "str | None"
    hook_params: "dict | None"


class RdsCreateDbSnapshotOperator(RdsBaseOperator):
    db_type: "str"
    db_identifier: "str"
    db_snapshot_identifier: "str"
    tags: "Sequence[TagTypeDef] | dict | None"
    wait_for_completion: "bool"


class RdsCopyDbSnapshotOperator(RdsBaseOperator):
    db_type: "str"
    source_db_snapshot_identifier: "str"
    target_db_snapshot_identifier: "str"
    kms_key_id: "str"
    tags: "Sequence[TagTypeDef] | dict | None"
    copy_tags: "bool"
    pre_signed_url: "str"
    option_group_name: "str"
    target_custom_availability_zone: "str"
    source_region: "str"
    wait_for_completion: "bool"


class RdsDeleteDbSnapshotOperator(RdsBaseOperator):
    db_type: "str"
    db_snapshot_identifier: "str"
    wait_for_completion: "bool"


class RdsStartExportTaskOperator(RdsBaseOperator):
    export_task_identifier: "str"
    source_arn: "str"
    s3_bucket_name: "str"
    iam_role_arn: "str"
    kms_key_id: "str"
    s3_prefix: "str"
    export_only: "list[str] | None"
    wait_for_completion: "bool"
    waiter_interval: "int"
    waiter_max_attempts: "int"


class RdsCancelExportTaskOperator(RdsBaseOperator):
    export_task_identifier: "str"
    wait_for_completion: "bool"
    check_interval: "int"
    max_attempts: "int"


class RdsCreateEventSubscriptionOperator(RdsBaseOperator):
    subscription_name: "str"
    sns_topic_arn: "str"
    source_type: "str"
    event_categories: "Sequence[str] | None"
    source_ids: "Sequence[str] | None"
    enabled: "bool"
    tags: "Sequence[TagTypeDef] | dict | None"
    wait_for_completion: "bool"


class RdsDeleteEventSubscriptionOperator(RdsBaseOperator):
    subscription_name: "str"


class RdsCreateDbInstanceOperator(RdsBaseOperator):
    db_instance_identifier: "str"
    db_instance_class: "str"
    engine: "str"
    rds_kwargs: "dict | None"
    wait_for_completion: "bool"
    deferrable: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"


class RdsDeleteDbInstanceOperator(RdsBaseOperator):
    db_instance_identifier: "str"
    rds_kwargs: "dict | None"
    wait_for_completion: "bool"
    deferrable: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"


class RdsStartDbOperator(RdsBaseOperator):
    db_identifier: "str"
    db_type: "RdsDbType | str"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class RdsStopDbOperator(RdsBaseOperator):
    db_identifier: "str"
    db_type: "RdsDbType | str"
    db_snapshot_identifier: "str | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class FlinkKubernetesSensor(BaseSensorOperator):
    application_name: "str"
    attach_log: "bool"
    namespace: "str | None"
    kubernetes_conn_id: "str"
    api_group: "str"
    api_version: "str"
    plural: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GlueDataBrewStartJobOperator(BaseOperator):
    job_name: "str"
    wait_for_completion: "bool"
    delay: "int"
    deferrable: "bool"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class EmrBaseSensor(BaseSensorOperator):
    aws_conn_id: "str | None"


class EmrServerlessJobSensor(BaseSensorOperator):
    application_id: "str"
    job_run_id: "str"
    target_states: "set | frozenset"
    aws_conn_id: "str | None"


class EmrServerlessApplicationSensor(BaseSensorOperator):
    application_id: "str"
    target_states: "set | frozenset"
    aws_conn_id: "str | None"


class EmrContainerSensor(BaseSensorOperator):
    virtual_cluster_id: "str"
    job_id: "str"
    max_retries: "int | None"
    aws_conn_id: "str | None"
    poll_interval: "int"
    deferrable: "bool"


class EmrNotebookExecutionSensor(EmrBaseSensor):
    notebook_execution_id: "str"
    target_states: "Iterable[str] | None"
    failed_states: "Iterable[str] | None"


class EmrJobFlowSensor(EmrBaseSensor):
    job_flow_id: "str"
    target_states: "Iterable[str] | None"
    failed_states: "Iterable[str] | None"
    max_attempts: "int"
    deferrable: "bool"


class EmrStepSensor(EmrBaseSensor):
    job_flow_id: "str"
    step_id: "str"
    target_states: "Iterable[str] | None"
    failed_states: "Iterable[str] | None"
    max_attempts: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class LambdaCreateFunctionOperator(AwsBaseOperator):
    function_name: "str"
    runtime: "str | None"
    role: "str"
    handler: "str | None"
    code: "dict"
    description: "str | None"
    timeout: "int | None"
    config: "dict | None"
    wait_for_completion: "bool"
    waiter_max_attempts: "int"
    waiter_delay: "int"
    deferrable: "bool"


class LambdaInvokeFunctionOperator(AwsBaseOperator):
    function_name: "str"
    log_type: "str | None"
    keep_empty_log_lines: "bool"
    qualifier: "str | None"
    invocation_type: "str | None"
    client_context: "str | None"
    payload: "bytes | str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class _CreateDatabricksWorkflowOperator(BaseOperator):
    task_id: "str"
    databricks_conn_id: "str"
    existing_clusters: "list[str] | None"
    extra_job_params: "dict[str, Any] | None"
    job_clusters: "list[dict[str, object]] | None"
    max_concurrent_runs: "int"
    notebook_params: "dict | None"
    tasks_to_convert: "list[BaseOperator] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureDataFactoryRunPipelineOperator(BaseOperator):
    pipeline_name: "str"
    azure_data_factory_conn_id: "str"
    resource_group_name: "str"
    factory_name: "str"
    wait_for_termination: "bool"
    reference_pipeline_run_id: "str | None"
    is_recovery: "bool | None"
    start_activity_name: "str | None"
    start_from_failure: "bool | None"
    parameters: "dict[str, Any] | None"
    timeout: "int"
    check_interval: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.python import _PythonDecoratedOperator
from airfly._vendor.airflow.operators.python import PythonVirtualenvOperator


class _PythonVirtualenvDecoratedOperator(
    _PythonDecoratedOperator, PythonVirtualenvOperator
):
    python_callable: "_empty"
    op_args: "_empty"
    op_kwargs: "_empty"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class RedisPubSubSensor(BaseSensorOperator):
    channels: "list[str] | str"
    redis_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.job import (
    KubernetesDeleteJobOperator,
    KubernetesJobOperator,
)
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.resource import (
    KubernetesCreateResourceOperator,
    KubernetesDeleteResourceOperator,
)
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class GKEDeleteClusterOperator(GoogleCloudBaseOperator):
    name: "str"
    location: "str"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    poll_interval: "int"


class GKECreateClusterOperator(GoogleCloudBaseOperator):
    location: "str"
    body: "dict | Cluster"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"
    poll_interval: "int"
    deferrable: "bool"


class GKEStartKueueInsideClusterOperator(GoogleCloudBaseOperator):
    location: "str"
    cluster_name: "str"
    kueue_version: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEStartPodOperator(KubernetesPodOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    regional: "bool | None"
    on_finish_action: "str | None"
    is_delete_operator_pod: "bool | None"


class GKEStartJobOperator(KubernetesJobOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"
    job_poll_interval: "float"


class GKEDescribeJobOperator(GoogleCloudBaseOperator):
    job_name: "str"
    location: "str"
    namespace: "str"
    cluster_name: "str"
    project_id: "str"
    use_internal_ip: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEListJobsOperator(GoogleCloudBaseOperator):
    location: "str"
    cluster_name: "str"
    namespace: "str | None"
    project_id: "str"
    use_internal_ip: "bool"
    do_xcom_push: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKECreateCustomResourceOperator(KubernetesCreateResourceOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEDeleteCustomResourceOperator(KubernetesDeleteResourceOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEStartKueueJobOperator(GKEStartJobOperator):
    queue_name: "str"


class GKEDeleteJobOperator(KubernetesDeleteJobOperator):
    location: "str"
    cluster_name: "str"
    use_internal_ip: "bool"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKESuspendJobOperator(GoogleCloudBaseOperator):
    name: "str"
    location: "str"
    namespace: "str"
    cluster_name: "str"
    project_id: "str"
    use_internal_ip: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GKEResumeJobOperator(GoogleCloudBaseOperator):
    name: "str"
    location: "str"
    namespace: "str"
    cluster_name: "str"
    project_id: "str"
    use_internal_ip: "bool"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.docker.operators.docker import DockerOperator


class DockerSwarmOperator(DockerOperator):
    image: "str"
    args: "str | list[str] | None"
    enable_logging: "bool"
    configs: "list[types.ConfigReference] | None"
    secrets: "list[types.SecretReference] | None"
    mode: "types.ServiceMode | None"
    networks: "list[str | types.NetworkAttachmentConfig] | None"
    placement: "types.Placement | list[types.Placement] | None"
    container_resources: "types.Resources | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PapermillOperator(BaseOperator):
    input_nb: "str | NoteBook | None"
    output_nb: "str | NoteBook | None"
    parameters: "dict | None"
    kernel_name: "str | None"
    language_name: "str | None"
    kernel_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DeleteModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class GetModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ExportModelOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    model_id: "str"
    output_config: "model_service.ExportModelRequest.OutputConfig | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListModelsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    filter: "str | None"
    page_size: "int | None"
    page_token: "str | None"
    read_mask: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class UploadModelOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    model: "Model | dict"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ListModelVersionsOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SetDefaultVersionOnModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class AddVersionAliasesOnModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    version_aliases: "Sequence[str]"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteVersionAliasesOnModelOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    version_aliases: "Sequence[str]"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DeleteModelVersionOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    model_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class DataprocMetastoreCreateBackupOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    backup: "dict | Backup"
    backup_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreCreateMetadataImportOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    metadata_import: "dict | MetadataImport"
    metadata_import_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    service: "dict | Service"
    service_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreDeleteBackupOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    backup_id: "str"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreDeleteServiceOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    service_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
    destination_gcs_folder: "str"
    project_id: "str"
    region: "str"
    service_id: "str"
    request_id: "str | None"
    database_dump_type: "DatabaseDumpSpec | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreGetServiceOperator(GoogleCloudBaseOperator):
    region: "str"
    project_id: "str"
    service_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreListBackupsOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    page_size: "int | None"
    page_token: "str | None"
    filter: "str | None"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    backup_project_id: "str"
    backup_region: "str"
    backup_service_id: "str"
    backup_id: "str"
    restore_type: "Restore | None"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class DataprocMetastoreUpdateServiceOperator(GoogleCloudBaseOperator):
    project_id: "str"
    region: "str"
    service_id: "str"
    service: "dict | Service"
    update_mask: "FieldMask"
    request_id: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class DecoratedOperator(BaseOperator):
    python_callable: "Callable"
    task_id: "str"
    op_args: "Collection[Any] | None"
    op_kwargs: "Mapping[str, Any] | None"
    kwargs_to_upstream: "dict[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class EcsBaseOperator(AwsBaseOperator):
    aws_conn_id: "str | None"
    region_name: "str | None"
    verify: "bool | str | None"
    botocore_config: "dict | None"
    region: "str | None | ArgNotSet"


class EcsCreateClusterOperator(EcsBaseOperator):
    cluster_name: "str"
    create_cluster_kwargs: "dict | None"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EcsDeleteClusterOperator(EcsBaseOperator):
    cluster_name: "str"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class EcsDeregisterTaskDefinitionOperator(EcsBaseOperator):
    task_definition: "str"
    wait_for_completion: "_empty"
    waiter_delay: "_empty"
    waiter_max_attempts: "_empty"


class EcsRegisterTaskDefinitionOperator(EcsBaseOperator):
    family: "str"
    container_definitions: "list[dict]"
    register_task_kwargs: "dict | None"
    wait_for_completion: "_empty"
    waiter_delay: "_empty"
    waiter_max_attempts: "_empty"


class EcsRunTaskOperator(EcsBaseOperator):
    task_definition: "str"
    cluster: "str"
    overrides: "dict"
    launch_type: "str"
    capacity_provider_strategy: "list | None"
    group: "str | None"
    placement_constraints: "list | None"
    placement_strategy: "list | None"
    platform_version: "str | None"
    network_configuration: "dict | None"
    tags: "dict | None"
    awslogs_group: "str | None"
    awslogs_region: "str | None"
    awslogs_stream_prefix: "str | None"
    awslogs_fetch_interval: "timedelta"
    propagate_tags: "str | None"
    quota_retry: "dict | None"
    reattach: "bool"
    number_logs_exception: "int"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class Neo4jOperator(BaseOperator):
    sql: "str"
    neo4j_conn_id: "str"
    parameters: "Iterable | Mapping[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class ComprehendBaseSensor(AwsBaseSensor):
    deferrable: "bool"


class ComprehendStartPiiEntitiesDetectionJobCompletedSensor(ComprehendBaseSensor):
    job_id: "str"
    max_retries: "int"
    poke_interval: "int"


class ComprehendCreateDocumentClassifierCompletedSensor(AwsBaseSensor):
    document_classifier_arn: "str"
    fail_on_warnings: "bool"
    max_retries: "int"
    poke_interval: "int"
    deferrable: "bool"
    aws_conn_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class FacebookAdsReportToGcsOperator(BaseOperator):
    bucket_name: "str"
    object_name: "str"
    fields: "list[str]"
    parameters: "dict[str, Any] | None"
    gzip: "bool"
    upload_as_account: "bool"
    api_version: "str | None"
    gcp_conn_id: "str"
    facebook_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.decorators.base import DecoratedOperator
from airfly._vendor.airflow.providers.docker.operators.docker import DockerOperator


class _DockerDecoratedOperator(DecoratedOperator, DockerOperator):
    use_dill: "_empty"
    python_command: "_empty"
    expect_airflow: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.common.sql.operators.sql import (
    SQLExecuteQueryOperator,
)


class JdbcOperator(SQLExecuteQueryOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SageMakerBaseSensor(BaseSensorOperator):
    aws_conn_id: "str | None"
    resource_type: "str"


class SageMakerEndpointSensor(SageMakerBaseSensor):
    endpoint_name: "_empty"


class SageMakerTransformSensor(SageMakerBaseSensor):
    job_name: "str"


class SageMakerTuningSensor(SageMakerBaseSensor):
    job_name: "str"


class SageMakerTrainingSensor(SageMakerBaseSensor):
    job_name: "_empty"
    print_log: "_empty"


class SageMakerPipelineSensor(SageMakerBaseSensor):
    pipeline_exec_arn: "str"
    verbose: "bool"


class SageMakerAutoMLSensor(SageMakerBaseSensor):
    job_name: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class TelegramOperator(BaseOperator):
    telegram_conn_id: "str"
    token: "str | None"
    chat_id: "str | None"
    text: "str"
    telegram_kwargs: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class CloudDataCatalogCreateEntryOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry_id: "str"
    entry: "dict | Entry"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateEntryGroupOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group_id: "str"
    entry_group: "dict | EntryGroup"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateTagOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    tag: "dict | Tag"
    template_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateTagTemplateOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template_id: "str"
    tag_template: "dict | TagTemplate"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogCreateTagTemplateFieldOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    tag_template_field_id: "str"
    tag_template_field: "dict | TagTemplateField"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteEntryOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteEntryGroupOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteTagOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    tag: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteTagTemplateOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    force: "bool"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogDeleteTagTemplateFieldOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    field: "str"
    force: "bool"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogGetEntryOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogGetEntryGroupOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    read_mask: "FieldMask"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogGetTagTemplateOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogListTagsOperator(GoogleCloudBaseOperator):
    location: "str"
    entry_group: "str"
    entry: "str"
    page_size: "int"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogLookupEntryOperator(GoogleCloudBaseOperator):
    linked_resource: "str | None"
    sql_resource: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogRenameTagTemplateFieldOperator(GoogleCloudBaseOperator):
    location: "str"
    tag_template: "str"
    field: "str"
    new_tag_template_field_id: "str"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogSearchCatalogOperator(GoogleCloudBaseOperator):
    scope: "dict | SearchCatalogRequest.Scope"
    query: "str"
    page_size: "int"
    order_by: "str | None"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateEntryOperator(GoogleCloudBaseOperator):
    entry: "dict | Entry"
    update_mask: "dict | FieldMask"
    location: "str | None"
    entry_group: "str | None"
    entry_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateTagOperator(GoogleCloudBaseOperator):
    tag: "dict | Tag"
    update_mask: "dict | FieldMask"
    location: "str | None"
    entry_group: "str | None"
    entry: "str | None"
    tag_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateTagTemplateOperator(GoogleCloudBaseOperator):
    tag_template: "dict | TagTemplate"
    update_mask: "dict | FieldMask"
    location: "str | None"
    tag_template_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class CloudDataCatalogUpdateTagTemplateFieldOperator(GoogleCloudBaseOperator):
    tag_template_field: "dict | TagTemplateField"
    update_mask: "dict | FieldMask"
    tag_template_field_name: "str | None"
    location: "str | None"
    tag_template: "str | None"
    tag_template_field_id: "str | None"
    project_id: "str"
    retry: "Retry | _MethodDefault"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.utils.mixins import AwsBaseHookMixin
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AwsBaseSensor(BaseSensorOperator, AwsBaseHookMixin):
    aws_conn_id: "str | None"
    region_name: "str | None"
    verify: "bool | str | None"
    botocore_config: "dict | None"
    region: "str | None | ArgNotSet"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpenSearchQueryOperator(BaseOperator):
    query: "dict | None"
    search_object: "Any | None"
    index_name: "str | None"
    opensearch_conn_id: "str"
    opensearch_conn_class: "type[OpenSearchConnectionClass] | None"
    log_query: "bool"


class OpenSearchCreateIndexOperator(BaseOperator):
    index_name: "str"
    index_body: "dict[str, Any]"
    opensearch_conn_id: "str"


class OpenSearchAddDocumentOperator(BaseOperator):
    index_name: "str | None"
    document: "dict[str, Any] | None"
    doc_id: "int | None"
    doc_class: "Any | None"
    opensearch_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class NeptuneStartDbClusterOperator(AwsBaseOperator):
    db_cluster_id: "str"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"


class NeptuneStopDbClusterOperator(AwsBaseOperator):
    db_cluster_id: "str"
    wait_for_completion: "bool"
    waiter_delay: "int"
    waiter_max_attempts: "int"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.slack.transfers.base_sql_to_slack import (
    BaseSqlToSlackOperator,
)


class SqlToSlackWebhookOperator(BaseSqlToSlackOperator):
    sql: "str"
    sql_conn_id: "str"
    slack_webhook_conn_id: "str | None"
    sql_hook_params: "dict | None"
    slack_channel: "str | None"
    slack_message: "str"
    results_df_name: "str"
    parameters: "list | tuple | Mapping[str, Any] | None"
    slack_conn_id: "str | ArgNotSet"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class KubernetesPodOperator(BaseOperator):
    kubernetes_conn_id: "str | None"
    namespace: "str | None"
    image: "str | None"
    name: "str | None"
    random_name_suffix: "bool"
    cmds: "list[str] | None"
    arguments: "list[str] | None"
    ports: "list[k8s.V1ContainerPort] | None"
    volume_mounts: "list[k8s.V1VolumeMount] | None"
    volumes: "list[k8s.V1Volume] | None"
    env_vars: "list[k8s.V1EnvVar] | dict[str, str] | None"
    env_from: "list[k8s.V1EnvFromSource] | None"
    secrets: "list[Secret] | None"
    in_cluster: "bool | None"
    cluster_context: "str | None"
    labels: "dict | None"
    reattach_on_restart: "bool"
    startup_timeout_seconds: "int"
    startup_check_interval_seconds: "int"
    get_logs: "bool"
    container_logs: "Iterable[str] | str | Literal[True]"
    image_pull_policy: "str | None"
    annotations: "dict | None"
    container_resources: "k8s.V1ResourceRequirements | None"
    affinity: "k8s.V1Affinity | None"
    config_file: "str | None"
    node_selector: "dict | None"
    image_pull_secrets: "list[k8s.V1LocalObjectReference] | None"
    service_account_name: "str | None"
    hostnetwork: "bool"
    host_aliases: "list[k8s.V1HostAlias] | None"
    tolerations: "list[k8s.V1Toleration] | None"
    security_context: "k8s.V1PodSecurityContext | dict | None"
    container_security_context: "k8s.V1SecurityContext | dict | None"
    dnspolicy: "str | None"
    dns_config: "k8s.V1PodDNSConfig | None"
    hostname: "str | None"
    subdomain: "str | None"
    schedulername: "str | None"
    full_pod_spec: "k8s.V1Pod | None"
    init_containers: "list[k8s.V1Container] | None"
    log_events_on_failure: "bool"
    do_xcom_push: "bool"
    pod_template_file: "str | None"
    pod_template_dict: "dict | None"
    priority_class_name: "str | None"
    pod_runtime_info_envs: "list[k8s.V1EnvVar] | None"
    termination_grace_period: "int | None"
    configmaps: "list[str] | None"
    skip_on_exit_code: "int | Container[int] | None"
    base_container_name: "str | None"
    deferrable: "bool"
    poll_interval: "float"
    log_pod_spec_on_failure: "bool"
    on_finish_action: "str"
    is_delete_operator_pod: "None | bool"
    termination_message_policy: "str"
    active_deadline_seconds: "int | None"
    callbacks: "type[KubernetesPodOperatorCallback] | None"
    progress_callback: "Callable[[str], None] | None"
    logging_interval: "int | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class GoogleAdsToGcsOperator(BaseOperator):
    client_ids: "list[str]"
    query: "str"
    attributes: "list[str]"
    bucket: "str"
    obj: "str"
    gcp_conn_id: "str"
    google_ads_conn_id: "str"
    page_size: "int"
    gzip: "bool"
    impersonation_chain: "str | Sequence[str] | None"
    api_version: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureDataExplorerQueryOperator(BaseOperator):
    query: "str"
    database: "str"
    options: "dict | None"
    azure_data_explorer_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ADLSListOperator(BaseOperator):
    path: "str"
    azure_data_lake_conn_id: "str"


class ADLSCreateObjectOperator(BaseOperator):
    file_system_name: "str"
    file_name: "str"
    data: "bytes | str | Iterable[AnyStr] | IO[AnyStr]"
    length: "int | None"
    replace: "bool"
    azure_data_lake_conn_id: "str"


class ADLSDeleteOperator(BaseOperator):
    path: "str"
    recursive: "bool"
    ignore_not_found: "bool"
    azure_data_lake_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class SqlSensor(BaseSensorOperator):
    conn_id: "str"
    sql: "str"
    parameters: "Mapping[str, Any] | None"
    success: "Callable[[Any], bool] | None"
    failure: "Callable[[Any], bool] | None"
    fail_on_empty: "bool"
    hook_params: "Mapping[str, Any] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GCSObjectExistenceSensor(BaseSensorOperator):
    bucket: "str"
    object: "str"
    use_glob: "bool"
    google_cloud_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    retry: "Retry"
    deferrable: "bool"


class GCSObjectExistenceAsyncSensor(GCSObjectExistenceSensor):
    pass


class GCSObjectUpdateSensor(BaseSensorOperator):
    bucket: "str"
    object: "str"
    ts_func: "Callable"
    google_cloud_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"


class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
    bucket: "str"
    prefix: "str"
    google_cloud_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"


class GCSUploadSessionCompleteSensor(BaseSensorOperator):
    bucket: "str"
    prefix: "str"
    inactivity_period: "float"
    min_objects: "int"
    previous_objects: "set[str] | None"
    allow_delete: "bool"
    google_cloud_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"
    deferrable: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.transfers.bigquery_to_sql import (
    BigQueryToSqlBaseOperator,
)


class BigQueryToMySqlOperator(BigQueryToSqlBaseOperator):
    mysql_table: "str | None"
    target_table_name: "str | None"
    mysql_conn_id: "str"
    dataset_id: "str | None"
    table_id: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AzureServiceBusCreateQueueOperator(BaseOperator):
    queue_name: "str"
    max_delivery_count: "int"
    dead_lettering_on_message_expiration: "bool"
    enable_batched_operations: "bool"
    azure_service_bus_conn_id: "str"


class AzureServiceBusSendMessageOperator(BaseOperator):
    queue_name: "str"
    message: "str | list[str]"
    batch: "bool"
    azure_service_bus_conn_id: "str"


class AzureServiceBusReceiveMessageOperator(BaseOperator):
    queue_name: "str"
    azure_service_bus_conn_id: "str"
    max_message_count: "int"
    max_wait_time: "float"


class AzureServiceBusDeleteQueueOperator(BaseOperator):
    queue_name: "str"
    azure_service_bus_conn_id: "str"


class AzureServiceBusTopicCreateOperator(BaseOperator):
    topic_name: "str"
    azure_service_bus_conn_id: "str"
    default_message_time_to_live: "datetime.timedelta | str | None"
    max_size_in_megabytes: "int | None"
    requires_duplicate_detection: "bool | None"
    duplicate_detection_history_time_window: "datetime.timedelta | str | None"
    enable_batched_operations: "bool | None"
    size_in_bytes: "int | None"
    filtering_messages_before_publishing: "bool | None"
    authorization_rules: "list[AuthorizationRule] | None"
    support_ordering: "bool | None"
    auto_delete_on_idle: "datetime.timedelta | str | None"
    enable_partitioning: "bool | None"
    enable_express: "bool | None"
    user_metadata: "str | None"
    max_message_size_in_kilobytes: "int | None"


class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
    topic_name: "str"
    subscription_name: "str"
    azure_service_bus_conn_id: "str"
    lock_duration: "datetime.timedelta | str | None"
    requires_session: "bool | None"
    default_message_time_to_live: "datetime.timedelta | str | None"
    dead_lettering_on_message_expiration: "bool | None"
    dead_lettering_on_filter_evaluation_exceptions: "bool | None"
    max_delivery_count: "int | None"
    enable_batched_operations: "bool | None"
    forward_to: "str | None"
    user_metadata: "str | None"
    forward_dead_lettered_messages_to: "str | None"
    auto_delete_on_idle: "datetime.timedelta | str | None"


class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
    topic_name: "str"
    subscription_name: "str"
    max_delivery_count: "int | None"
    dead_lettering_on_message_expiration: "bool | None"
    enable_batched_operations: "bool | None"
    azure_service_bus_conn_id: "str"


class ASBReceiveSubscriptionMessageOperator(BaseOperator):
    topic_name: "str"
    subscription_name: "str"
    max_message_count: "int | None"
    max_wait_time: "float | None"
    azure_service_bus_conn_id: "str"


class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
    topic_name: "str"
    subscription_name: "str"
    azure_service_bus_conn_id: "str"


class AzureServiceBusTopicDeleteOperator(BaseOperator):
    topic_name: "str"
    azure_service_bus_conn_id: "str"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class AsanaCreateTaskOperator(BaseOperator):
    conn_id: "str"
    name: "str"
    task_parameters: "dict | None"


class AsanaUpdateTaskOperator(BaseOperator):
    conn_id: "str"
    asana_task_gid: "str"
    task_parameters: "dict"


class AsanaDeleteTaskOperator(BaseOperator):
    conn_id: "str"
    asana_task_gid: "str"


class AsanaFindTaskOperator(BaseOperator):
    conn_id: "str"
    search_parameters: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class OpenAIEmbeddingOperator(BaseOperator):
    conn_id: "str"
    input_text: "str | list[str] | list[int] | list[list[int]]"
    model: "str"
    embedding_kwargs: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class SparkSubmitOperator(BaseOperator):
    application: "str"
    conf: "dict[str, Any] | None"
    conn_id: "str"
    files: "str | None"
    py_files: "str | None"
    archives: "str | None"
    driver_class_path: "str | None"
    jars: "str | None"
    java_class: "str | None"
    packages: "str | None"
    exclude_packages: "str | None"
    repositories: "str | None"
    total_executor_cores: "int | None"
    executor_cores: "int | None"
    executor_memory: "str | None"
    driver_memory: "str | None"
    keytab: "str | None"
    principal: "str | None"
    proxy_user: "str | None"
    name: "str"
    num_executors: "int | None"
    status_poll_interval: "int"
    application_args: "list[Any] | None"
    env_vars: "dict[str, Any] | None"
    verbose: "bool"
    spark_binary: "str | None"
    properties_file: "str | None"
    yarn_queue: "str | None"
    deploy_mode: "str | None"
    use_krb5ccache: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class PsrpOperator(BaseOperator):
    psrp_conn_id: "str"
    command: "str | None"
    powershell: "str | None"
    cmdlet: "str | None"
    arguments: "list[str] | None"
    parameters: "dict[str, str] | None"
    logging_level: "int"
    runspace_options: "dict[str, Any] | None"
    wsman_options: "dict[str, Any] | None"
    psrp_session_init: "Command | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator
from airfly._vendor.airflow.providers.cncf.kubernetes.operators.pod import (
    KubernetesPodOperator,
)


class KubernetesJobOperator(KubernetesPodOperator):
    job_template_file: "str | None"
    full_job_spec: "k8s.V1Job | None"
    backoff_limit: "int | None"
    completion_mode: "str | None"
    completions: "int | None"
    manual_selector: "bool | None"
    parallelism: "int | None"
    selector: "k8s.V1LabelSelector | None"
    suspend: "bool | None"
    ttl_seconds_after_finished: "int | None"
    wait_until_job_complete: "bool"
    job_poll_interval: "float"
    deferrable: "bool"


class KubernetesDeleteJobOperator(BaseOperator):
    name: "str"
    namespace: "str"
    kubernetes_conn_id: "str | None"
    config_file: "str | None"
    in_cluster: "bool | None"
    cluster_context: "str | None"
    delete_on_status: "str | None"
    wait_for_completion: "bool"
    poll_interval: "float"


class KubernetesPatchJobOperator(BaseOperator):
    name: "str"
    namespace: "str"
    body: "object"
    kubernetes_conn_id: "str | None"
    config_file: "str | None"
    in_cluster: "bool | None"
    cluster_context: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class ComputeEngineBaseOperator(GoogleCloudBaseOperator):
    zone: "str"
    resource_id: "str | None"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineInsertInstanceOperator(ComputeEngineBaseOperator):
    body: "dict"
    zone: "str"
    resource_id: "str | None"
    project_id: "str"
    request_id: "str | None"
    retry: "Retry | None"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineInsertInstanceFromTemplateOperator(ComputeEngineBaseOperator):
    source_instance_template: "str"
    body: "dict"
    zone: "str"
    resource_id: "str | None"
    project_id: "str"
    request_id: "str | None"
    retry: "Retry | None"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineDeleteInstanceOperator(ComputeEngineBaseOperator):
    resource_id: "str"
    zone: "str"
    request_id: "str | None"
    project_id: "str"
    retry: "Retry | None"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineStartInstanceOperator(ComputeEngineBaseOperator):
    zone: "str"
    resource_id: "str | None"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineStopInstanceOperator(ComputeEngineBaseOperator):
    zone: "str"
    resource_id: "str | None"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
    zone: "str"
    resource_id: "str"
    body: "dict"
    project_id: "str"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineInsertInstanceTemplateOperator(ComputeEngineBaseOperator):
    body: "dict"
    project_id: "str"
    resource_id: "str | None"
    request_id: "str | None"
    retry: "Retry | None"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineDeleteInstanceTemplateOperator(ComputeEngineBaseOperator):
    resource_id: "str"
    request_id: "str | None"
    project_id: "str"
    retry: "Retry | None"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
    resource_id: "str"
    body_patch: "dict"
    project_id: "str"
    request_id: "str | None"
    gcp_conn_id: "str"
    api_version: "str"
    validate_body: "bool"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(
    ComputeEngineBaseOperator
):
    resource_id: "str"
    zone: "str"
    source_template: "str"
    destination_template: "str"
    project_id: "str"
    update_policy: "dict[str, Any] | None"
    request_id: "str | None"
    gcp_conn_id: "str"
    api_version: "_empty"
    impersonation_chain: "str | Sequence[str] | None"


class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator):
    body: "dict"
    zone: "str"
    project_id: "str"
    resource_id: "str | None"
    request_id: "str | None"
    gcp_conn_id: "str"
    api_version: "_empty"
    retry: "Retry | None"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    impersonation_chain: "str | Sequence[str] | None"
    validate_body: "bool"


class ComputeEngineDeleteInstanceGroupManagerOperator(ComputeEngineBaseOperator):
    resource_id: "str"
    zone: "str"
    project_id: "str"
    request_id: "str | None"
    gcp_conn_id: "str"
    api_version: "_empty"
    retry: "Retry | None"
    timeout: "float | None"
    metadata: "Sequence[tuple[str, str]]"
    impersonation_chain: "str | Sequence[str] | None"
    validate_body: "bool"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class GoogleDriveFileExistenceSensor(BaseSensorOperator):
    folder_id: "str"
    file_name: "str"
    drive_id: "str | None"
    gcp_conn_id: "str"
    delegate_to: "str | None"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.sensors.base import BaseSensorOperator


class AnalyticDBSparkSensor(BaseSensorOperator):
    app_id: "str"
    adb_spark_conn_id: "str"
    region: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor


class CloudFormationCreateStackSensor(AwsBaseSensor):
    stack_name: "_empty"


class CloudFormationDeleteStackSensor(AwsBaseSensor):
    stack_name: "str"
    aws_conn_id: "str | None"
    region_name: "str | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.operators.python import ShortCircuitOperator
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)
from airfly._vendor.airflow.providers.amazon.aws.utils.mixins import AwsBaseHookMixin


class AppflowBaseOperator(AwsBaseOperator):
    flow_name: "str"
    flow_update: "bool"
    source: "str | None"
    source_field: "str | None"
    filter_date: "str | None"
    poll_interval: "int"
    max_attempts: "int"
    wait_for_completion: "bool"


class AppflowRunOperator(AppflowBaseOperator):
    flow_name: "str"
    source: "str | None"
    poll_interval: "int"
    wait_for_completion: "bool"


class AppflowRunFullOperator(AppflowBaseOperator):
    source: "str"
    flow_name: "str"
    poll_interval: "int"
    wait_for_completion: "bool"


class AppflowRunBeforeOperator(AppflowBaseOperator):
    source: "str"
    flow_name: "str"
    source_field: "str"
    filter_date: "str"
    poll_interval: "int"
    wait_for_completion: "bool"


class AppflowRunAfterOperator(AppflowBaseOperator):
    source: "str"
    flow_name: "str"
    source_field: "str"
    filter_date: "str"
    poll_interval: "int"
    wait_for_completion: "bool"


class AppflowRunDailyOperator(AppflowBaseOperator):
    source: "str"
    flow_name: "str"
    source_field: "str"
    filter_date: "str"
    poll_interval: "int"
    wait_for_completion: "bool"


class AppflowRecordsShortCircuitOperator(ShortCircuitOperator, AwsBaseHookMixin):
    flow_name: "str"
    appflow_run_task_id: "str"
    ignore_downstream_trigger_rules: "bool"
    aws_conn_id: "str | None"
    region_name: "str | None"
    verify: "bool | str | None"
    botocore_config: "dict | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class MLEngineStartBatchPredictionJobOperator(GoogleCloudBaseOperator):
    pass


class MLEngineManageModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineCreateModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineGetModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineDeleteModelOperator(GoogleCloudBaseOperator):
    pass


class MLEngineManageVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineCreateVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineSetDefaultVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineListVersionsOperator(GoogleCloudBaseOperator):
    pass


class MLEngineDeleteVersionOperator(GoogleCloudBaseOperator):
    pass


class MLEngineStartTrainingJobOperator(GoogleCloudBaseOperator):
    pass


class MLEngineTrainingCancelJobOperator(GoogleCloudBaseOperator):
    pass



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.google.cloud.operators.cloud_base import (
    GoogleCloudBaseOperator,
)


class SpannerDeployInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    configuration_name: "str"
    node_count: "int"
    display_name: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerDeleteInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerQueryDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    query: "str | list[str]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerDeployDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    ddl_statements: "list[str]"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerUpdateDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    ddl_statements: "list[str]"
    project_id: "str"
    operation_id: "str | None"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"


class SpannerDeleteDatabaseInstanceOperator(GoogleCloudBaseOperator):
    instance_id: "str"
    database_id: "str"
    project_id: "str"
    gcp_conn_id: "str"
    impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.models.baseoperator import BaseOperator


class ProduceToTopicOperator(BaseOperator):
    topic: "str"
    producer_function: "str | Callable[..., Any]"
    kafka_config_id: "str"
    producer_function_args: "Sequence[Any] | None"
    producer_function_kwargs: "dict[Any, Any] | None"
    delivery_callback: "str | None"
    synchronous: "bool"
    poll_timeout: "float"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.microsoft.azure.operators.adls import (
    ADLSListOperator,
)


class ADLSToGCSOperator(ADLSListOperator):
    src_adls: "str"
    dest_gcs: "str"
    azure_data_lake_conn_id: "str"
    gcp_conn_id: "str"
    replace: "bool"
    gzip: "bool"
    google_impersonation_chain: "str | Sequence[str] | None"



# Auto generated by 'inv collect-airflow'
from airfly._vendor.airflow.providers.amazon.aws.operators.base_aws import (
    AwsBaseOperator,
)


class StepFunctionStartExecutionOperator(AwsBaseOperator):
    state_machine_arn: "str"
    name: "str | None"
    is_redrive_execution: "bool"
    state_machine_input: "dict | str | None"
    waiter_max_attempts: "int"
    waiter_delay: "int"
    deferrable: "bool"


class StepFunctionGetExecutionOutputOperator(AwsBaseOperator):
    execution_arn: "str"
